# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatabaseInstanceArgs', 'DatabaseInstance']

@pulumi.input_type
class DatabaseInstanceArgs:
    def __init__(__self__, *,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]] = None,
                 enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 parent_instance_ref: Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']] = None,
                 provider_config: Optional[pulumi.Input['DatabaseInstanceProviderConfigArgs']] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DatabaseInstance resource.
        :param pulumi.Input[_builtins.str] capacity: The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]] custom_tags: Custom tags associated with the instance. This field is only included on create and update responses
        :param pulumi.Input[_builtins.bool] enable_pg_native_login: Whether to enable PG native password login on the instance. Defaults to false
        :param pulumi.Input[_builtins.bool] enable_readable_secondaries: Whether to enable secondaries to serve read-only traffic. Defaults to false
        :param pulumi.Input[_builtins.str] name: The name of the instance. This is the unique identifier for the instance
        :param pulumi.Input[_builtins.int] node_count: The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        :param pulumi.Input['DatabaseInstanceParentInstanceRefArgs'] parent_instance_ref: The ref of the parent instance. This is only available if the instance is
               child instance.
               Input: For specifying the parent instance to create a child instance. Optional.
               Output: Only populated if provided as input to create a child instance
        :param pulumi.Input['DatabaseInstanceProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.bool] purge_on_delete: Purge the resource on delete
        :param pulumi.Input[_builtins.int] retention_window_in_days: The retention window for the instance. This is the time window in days
               for which the historical data is retained. The default value is 7 days.
               Valid values are 2 to 35 days
        :param pulumi.Input[_builtins.bool] stopped: Whether to stop the instance. An input only param, see effective_stopped for the output
        :param pulumi.Input[_builtins.str] usage_policy_id: The desired usage policy to associate with the instance
        """
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if custom_tags is not None:
            pulumi.set(__self__, "custom_tags", custom_tags)
        if enable_pg_native_login is not None:
            pulumi.set(__self__, "enable_pg_native_login", enable_pg_native_login)
        if enable_readable_secondaries is not None:
            pulumi.set(__self__, "enable_readable_secondaries", enable_readable_secondaries)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_count is not None:
            pulumi.set(__self__, "node_count", node_count)
        if parent_instance_ref is not None:
            pulumi.set(__self__, "parent_instance_ref", parent_instance_ref)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if purge_on_delete is not None:
            pulumi.set(__self__, "purge_on_delete", purge_on_delete)
        if retention_window_in_days is not None:
            pulumi.set(__self__, "retention_window_in_days", retention_window_in_days)
        if stopped is not None:
            pulumi.set(__self__, "stopped", stopped)
        if usage_policy_id is not None:
            pulumi.set(__self__, "usage_policy_id", usage_policy_id)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "capacity", value)

    @_builtins.property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]]:
        """
        Custom tags associated with the instance. This field is only included on create and update responses
        """
        return pulumi.get(self, "custom_tags")

    @custom_tags.setter
    def custom_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]]):
        pulumi.set(self, "custom_tags", value)

    @_builtins.property
    @pulumi.getter(name="enablePgNativeLogin")
    def enable_pg_native_login(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable PG native password login on the instance. Defaults to false
        """
        return pulumi.get(self, "enable_pg_native_login")

    @enable_pg_native_login.setter
    def enable_pg_native_login(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_pg_native_login", value)

    @_builtins.property
    @pulumi.getter(name="enableReadableSecondaries")
    def enable_readable_secondaries(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable secondaries to serve read-only traffic. Defaults to false
        """
        return pulumi.get(self, "enable_readable_secondaries")

    @enable_readable_secondaries.setter
    def enable_readable_secondaries(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_readable_secondaries", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the instance. This is the unique identifier for the instance
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        """
        return pulumi.get(self, "node_count")

    @node_count.setter
    def node_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "node_count", value)

    @_builtins.property
    @pulumi.getter(name="parentInstanceRef")
    def parent_instance_ref(self) -> Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']]:
        """
        The ref of the parent instance. This is only available if the instance is
        child instance.
        Input: For specifying the parent instance to create a child instance. Optional.
        Output: Only populated if provided as input to create a child instance
        """
        return pulumi.get(self, "parent_instance_ref")

    @parent_instance_ref.setter
    def parent_instance_ref(self, value: Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']]):
        pulumi.set(self, "parent_instance_ref", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DatabaseInstanceProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DatabaseInstanceProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Purge the resource on delete
        """
        return pulumi.get(self, "purge_on_delete")

    @purge_on_delete.setter
    def purge_on_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "purge_on_delete", value)

    @_builtins.property
    @pulumi.getter(name="retentionWindowInDays")
    def retention_window_in_days(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The retention window for the instance. This is the time window in days
        for which the historical data is retained. The default value is 7 days.
        Valid values are 2 to 35 days
        """
        return pulumi.get(self, "retention_window_in_days")

    @retention_window_in_days.setter
    def retention_window_in_days(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "retention_window_in_days", value)

    @_builtins.property
    @pulumi.getter
    def stopped(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to stop the instance. An input only param, see effective_stopped for the output
        """
        return pulumi.get(self, "stopped")

    @stopped.setter
    def stopped(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "stopped", value)

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The desired usage policy to associate with the instance
        """
        return pulumi.get(self, "usage_policy_id")

    @usage_policy_id.setter
    def usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage_policy_id", value)


@pulumi.input_type
class _DatabaseInstanceState:
    def __init__(__self__, *,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 child_instance_refs: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceChildInstanceRefArgs']]]] = None,
                 creation_time: Optional[pulumi.Input[_builtins.str]] = None,
                 creator: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]] = None,
                 effective_capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceEffectiveCustomTagArgs']]]] = None,
                 effective_enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 effective_enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 effective_node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 effective_retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 effective_stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 effective_usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 parent_instance_ref: Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']] = None,
                 pg_version: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['DatabaseInstanceProviderConfigArgs']] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 read_only_dns: Optional[pulumi.Input[_builtins.str]] = None,
                 read_write_dns: Optional[pulumi.Input[_builtins.str]] = None,
                 retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 uid: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DatabaseInstance resources.
        :param pulumi.Input[_builtins.str] capacity: The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceChildInstanceRefArgs']]] child_instance_refs: (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
               parent instance
        :param pulumi.Input[_builtins.str] creation_time: (string) - The timestamp when the instance was created
        :param pulumi.Input[_builtins.str] creator: (string) - The email of the creator of the instance
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]] custom_tags: Custom tags associated with the instance. This field is only included on create and update responses
        :param pulumi.Input[_builtins.str] effective_capacity: (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceEffectiveCustomTagArgs']]] effective_custom_tags: (list of CustomTag) - The recorded custom tags associated with the instance.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.bool] effective_enable_pg_native_login: (boolean) - Whether the instance has PG native password login enabled.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.bool] effective_enable_readable_secondaries: (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.int] effective_node_count: (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.int] effective_retention_window_in_days: (integer) - The retention window for the instance. This is the time window in days
               for which the historical data is retained.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.bool] effective_stopped: (boolean) - Whether the instance is stopped.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.str] effective_usage_policy_id: (string) - The policy that is applied to the instance.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.bool] enable_pg_native_login: Whether to enable PG native password login on the instance. Defaults to false
        :param pulumi.Input[_builtins.bool] enable_readable_secondaries: Whether to enable secondaries to serve read-only traffic. Defaults to false
        :param pulumi.Input[_builtins.str] name: The name of the instance. This is the unique identifier for the instance
        :param pulumi.Input[_builtins.int] node_count: The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        :param pulumi.Input['DatabaseInstanceParentInstanceRefArgs'] parent_instance_ref: The ref of the parent instance. This is only available if the instance is
               child instance.
               Input: For specifying the parent instance to create a child instance. Optional.
               Output: Only populated if provided as input to create a child instance
        :param pulumi.Input[_builtins.str] pg_version: (string) - The version of Postgres running on the instance
        :param pulumi.Input['DatabaseInstanceProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.bool] purge_on_delete: Purge the resource on delete
        :param pulumi.Input[_builtins.str] read_only_dns: (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
               enable_readable_secondaries is true
        :param pulumi.Input[_builtins.str] read_write_dns: (string) - The DNS endpoint to connect to the instance for read+write access
        :param pulumi.Input[_builtins.int] retention_window_in_days: The retention window for the instance. This is the time window in days
               for which the historical data is retained. The default value is 7 days.
               Valid values are 2 to 35 days
        :param pulumi.Input[_builtins.str] state: (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        :param pulumi.Input[_builtins.bool] stopped: Whether to stop the instance. An input only param, see effective_stopped for the output
        :param pulumi.Input[_builtins.str] uid: (string) - Id of the ref database instance
        :param pulumi.Input[_builtins.str] usage_policy_id: The desired usage policy to associate with the instance
        """
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if child_instance_refs is not None:
            pulumi.set(__self__, "child_instance_refs", child_instance_refs)
        if creation_time is not None:
            pulumi.set(__self__, "creation_time", creation_time)
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if custom_tags is not None:
            pulumi.set(__self__, "custom_tags", custom_tags)
        if effective_capacity is not None:
            pulumi.set(__self__, "effective_capacity", effective_capacity)
        if effective_custom_tags is not None:
            pulumi.set(__self__, "effective_custom_tags", effective_custom_tags)
        if effective_enable_pg_native_login is not None:
            pulumi.set(__self__, "effective_enable_pg_native_login", effective_enable_pg_native_login)
        if effective_enable_readable_secondaries is not None:
            pulumi.set(__self__, "effective_enable_readable_secondaries", effective_enable_readable_secondaries)
        if effective_node_count is not None:
            pulumi.set(__self__, "effective_node_count", effective_node_count)
        if effective_retention_window_in_days is not None:
            pulumi.set(__self__, "effective_retention_window_in_days", effective_retention_window_in_days)
        if effective_stopped is not None:
            pulumi.set(__self__, "effective_stopped", effective_stopped)
        if effective_usage_policy_id is not None:
            pulumi.set(__self__, "effective_usage_policy_id", effective_usage_policy_id)
        if enable_pg_native_login is not None:
            pulumi.set(__self__, "enable_pg_native_login", enable_pg_native_login)
        if enable_readable_secondaries is not None:
            pulumi.set(__self__, "enable_readable_secondaries", enable_readable_secondaries)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_count is not None:
            pulumi.set(__self__, "node_count", node_count)
        if parent_instance_ref is not None:
            pulumi.set(__self__, "parent_instance_ref", parent_instance_ref)
        if pg_version is not None:
            pulumi.set(__self__, "pg_version", pg_version)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if purge_on_delete is not None:
            pulumi.set(__self__, "purge_on_delete", purge_on_delete)
        if read_only_dns is not None:
            pulumi.set(__self__, "read_only_dns", read_only_dns)
        if read_write_dns is not None:
            pulumi.set(__self__, "read_write_dns", read_write_dns)
        if retention_window_in_days is not None:
            pulumi.set(__self__, "retention_window_in_days", retention_window_in_days)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if stopped is not None:
            pulumi.set(__self__, "stopped", stopped)
        if uid is not None:
            pulumi.set(__self__, "uid", uid)
        if usage_policy_id is not None:
            pulumi.set(__self__, "usage_policy_id", usage_policy_id)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "capacity", value)

    @_builtins.property
    @pulumi.getter(name="childInstanceRefs")
    def child_instance_refs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceChildInstanceRefArgs']]]]:
        """
        (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
        parent instance
        """
        return pulumi.get(self, "child_instance_refs")

    @child_instance_refs.setter
    def child_instance_refs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceChildInstanceRefArgs']]]]):
        pulumi.set(self, "child_instance_refs", value)

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The timestamp when the instance was created
        """
        return pulumi.get(self, "creation_time")

    @creation_time.setter
    def creation_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creation_time", value)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The email of the creator of the instance
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator", value)

    @_builtins.property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]]:
        """
        Custom tags associated with the instance. This field is only included on create and update responses
        """
        return pulumi.get(self, "custom_tags")

    @custom_tags.setter
    def custom_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceCustomTagArgs']]]]):
        pulumi.set(self, "custom_tags", value)

    @_builtins.property
    @pulumi.getter(name="effectiveCapacity")
    def effective_capacity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_capacity")

    @effective_capacity.setter
    def effective_capacity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_capacity", value)

    @_builtins.property
    @pulumi.getter(name="effectiveCustomTags")
    def effective_custom_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceEffectiveCustomTagArgs']]]]:
        """
        (list of CustomTag) - The recorded custom tags associated with the instance.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_custom_tags")

    @effective_custom_tags.setter
    def effective_custom_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseInstanceEffectiveCustomTagArgs']]]]):
        pulumi.set(self, "effective_custom_tags", value)

    @_builtins.property
    @pulumi.getter(name="effectiveEnablePgNativeLogin")
    def effective_enable_pg_native_login(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (boolean) - Whether the instance has PG native password login enabled.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_enable_pg_native_login")

    @effective_enable_pg_native_login.setter
    def effective_enable_pg_native_login(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "effective_enable_pg_native_login", value)

    @_builtins.property
    @pulumi.getter(name="effectiveEnableReadableSecondaries")
    def effective_enable_readable_secondaries(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_enable_readable_secondaries")

    @effective_enable_readable_secondaries.setter
    def effective_enable_readable_secondaries(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "effective_enable_readable_secondaries", value)

    @_builtins.property
    @pulumi.getter(name="effectiveNodeCount")
    def effective_node_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_node_count")

    @effective_node_count.setter
    def effective_node_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "effective_node_count", value)

    @_builtins.property
    @pulumi.getter(name="effectiveRetentionWindowInDays")
    def effective_retention_window_in_days(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - The retention window for the instance. This is the time window in days
        for which the historical data is retained.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_retention_window_in_days")

    @effective_retention_window_in_days.setter
    def effective_retention_window_in_days(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "effective_retention_window_in_days", value)

    @_builtins.property
    @pulumi.getter(name="effectiveStopped")
    def effective_stopped(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        (boolean) - Whether the instance is stopped.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_stopped")

    @effective_stopped.setter
    def effective_stopped(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "effective_stopped", value)

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The policy that is applied to the instance.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_usage_policy_id")

    @effective_usage_policy_id.setter
    def effective_usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_usage_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="enablePgNativeLogin")
    def enable_pg_native_login(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable PG native password login on the instance. Defaults to false
        """
        return pulumi.get(self, "enable_pg_native_login")

    @enable_pg_native_login.setter
    def enable_pg_native_login(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_pg_native_login", value)

    @_builtins.property
    @pulumi.getter(name="enableReadableSecondaries")
    def enable_readable_secondaries(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable secondaries to serve read-only traffic. Defaults to false
        """
        return pulumi.get(self, "enable_readable_secondaries")

    @enable_readable_secondaries.setter
    def enable_readable_secondaries(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_readable_secondaries", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the instance. This is the unique identifier for the instance
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        """
        return pulumi.get(self, "node_count")

    @node_count.setter
    def node_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "node_count", value)

    @_builtins.property
    @pulumi.getter(name="parentInstanceRef")
    def parent_instance_ref(self) -> Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']]:
        """
        The ref of the parent instance. This is only available if the instance is
        child instance.
        Input: For specifying the parent instance to create a child instance. Optional.
        Output: Only populated if provided as input to create a child instance
        """
        return pulumi.get(self, "parent_instance_ref")

    @parent_instance_ref.setter
    def parent_instance_ref(self, value: Optional[pulumi.Input['DatabaseInstanceParentInstanceRefArgs']]):
        pulumi.set(self, "parent_instance_ref", value)

    @_builtins.property
    @pulumi.getter(name="pgVersion")
    def pg_version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The version of Postgres running on the instance
        """
        return pulumi.get(self, "pg_version")

    @pg_version.setter
    def pg_version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pg_version", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DatabaseInstanceProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DatabaseInstanceProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Purge the resource on delete
        """
        return pulumi.get(self, "purge_on_delete")

    @purge_on_delete.setter
    def purge_on_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "purge_on_delete", value)

    @_builtins.property
    @pulumi.getter(name="readOnlyDns")
    def read_only_dns(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
        enable_readable_secondaries is true
        """
        return pulumi.get(self, "read_only_dns")

    @read_only_dns.setter
    def read_only_dns(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "read_only_dns", value)

    @_builtins.property
    @pulumi.getter(name="readWriteDns")
    def read_write_dns(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The DNS endpoint to connect to the instance for read+write access
        """
        return pulumi.get(self, "read_write_dns")

    @read_write_dns.setter
    def read_write_dns(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "read_write_dns", value)

    @_builtins.property
    @pulumi.getter(name="retentionWindowInDays")
    def retention_window_in_days(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The retention window for the instance. This is the time window in days
        for which the historical data is retained. The default value is 7 days.
        Valid values are 2 to 35 days
        """
        return pulumi.get(self, "retention_window_in_days")

    @retention_window_in_days.setter
    def retention_window_in_days(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "retention_window_in_days", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter
    def stopped(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to stop the instance. An input only param, see effective_stopped for the output
        """
        return pulumi.get(self, "stopped")

    @stopped.setter
    def stopped(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "stopped", value)

    @_builtins.property
    @pulumi.getter
    def uid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Id of the ref database instance
        """
        return pulumi.get(self, "uid")

    @uid.setter
    def uid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "uid", value)

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The desired usage policy to associate with the instance
        """
        return pulumi.get(self, "usage_policy_id")

    @usage_policy_id.setter
    def usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage_policy_id", value)


@pulumi.type_token("databricks:index/databaseInstance:DatabaseInstance")
class DatabaseInstance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]]] = None,
                 enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 parent_instance_ref: Optional[pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']]] = None,
                 provider_config: Optional[pulumi.Input[Union['DatabaseInstanceProviderConfigArgs', 'DatabaseInstanceProviderConfigArgsDict']]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Lakebase Database Instances are managed Postgres instances, composed of a primary Postgres compute instance and 0 or more read replica instances.

        ## Example Usage

        ### Basic Example

        This example creates a simple Database Instance with the specified name and capacity.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_2")
        ```

        ### Example with Readable Secondaries

        This example creates a Database Instance with readable secondaries (and HA) enabled.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_2",
            node_count=2,
            enable_readable_secondaries=True)
        ```

        ### Example Child Instance Created From Parent

        This example creates a child Database Instance from a specified parent Database Instance at the current point in time.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        child = databricks.DatabaseInstance("child",
            name="my-database-instance",
            capacity="CU_2",
            parent_instance_ref={
                "name": "my-parent-instance",
            })
        ```

        ### Example with a usage policy and custom tags

        This example creates a Database Instance with an associated usage policy and custom tags.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_8",
            usage_policy_id="948192fa-a98b-498f-a09b-ecee79d8b983",
            custom_tags=[
                {
                    "key": "custom_tag_key1",
                    "value": "custom_tag_value1",
                },
                {
                    "key": "custom_tag_key2",
                    "value": "custom_tag_value2",
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] capacity: The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]] custom_tags: Custom tags associated with the instance. This field is only included on create and update responses
        :param pulumi.Input[_builtins.bool] enable_pg_native_login: Whether to enable PG native password login on the instance. Defaults to false
        :param pulumi.Input[_builtins.bool] enable_readable_secondaries: Whether to enable secondaries to serve read-only traffic. Defaults to false
        :param pulumi.Input[_builtins.str] name: The name of the instance. This is the unique identifier for the instance
        :param pulumi.Input[_builtins.int] node_count: The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        :param pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']] parent_instance_ref: The ref of the parent instance. This is only available if the instance is
               child instance.
               Input: For specifying the parent instance to create a child instance. Optional.
               Output: Only populated if provided as input to create a child instance
        :param pulumi.Input[Union['DatabaseInstanceProviderConfigArgs', 'DatabaseInstanceProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.bool] purge_on_delete: Purge the resource on delete
        :param pulumi.Input[_builtins.int] retention_window_in_days: The retention window for the instance. This is the time window in days
               for which the historical data is retained. The default value is 7 days.
               Valid values are 2 to 35 days
        :param pulumi.Input[_builtins.bool] stopped: Whether to stop the instance. An input only param, see effective_stopped for the output
        :param pulumi.Input[_builtins.str] usage_policy_id: The desired usage policy to associate with the instance
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DatabaseInstanceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Lakebase Database Instances are managed Postgres instances, composed of a primary Postgres compute instance and 0 or more read replica instances.

        ## Example Usage

        ### Basic Example

        This example creates a simple Database Instance with the specified name and capacity.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_2")
        ```

        ### Example with Readable Secondaries

        This example creates a Database Instance with readable secondaries (and HA) enabled.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_2",
            node_count=2,
            enable_readable_secondaries=True)
        ```

        ### Example Child Instance Created From Parent

        This example creates a child Database Instance from a specified parent Database Instance at the current point in time.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        child = databricks.DatabaseInstance("child",
            name="my-database-instance",
            capacity="CU_2",
            parent_instance_ref={
                "name": "my-parent-instance",
            })
        ```

        ### Example with a usage policy and custom tags

        This example creates a Database Instance with an associated usage policy and custom tags.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseInstance("this",
            name="my-database-instance",
            capacity="CU_8",
            usage_policy_id="948192fa-a98b-498f-a09b-ecee79d8b983",
            custom_tags=[
                {
                    "key": "custom_tag_key1",
                    "value": "custom_tag_value1",
                },
                {
                    "key": "custom_tag_key2",
                    "value": "custom_tag_value2",
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 capacity: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]]] = None,
                 enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 node_count: Optional[pulumi.Input[_builtins.int]] = None,
                 parent_instance_ref: Optional[pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']]] = None,
                 provider_config: Optional[pulumi.Input[Union['DatabaseInstanceProviderConfigArgs', 'DatabaseInstanceProviderConfigArgsDict']]] = None,
                 purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
                 stopped: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseInstanceArgs.__new__(DatabaseInstanceArgs)

            __props__.__dict__["capacity"] = capacity
            __props__.__dict__["custom_tags"] = custom_tags
            __props__.__dict__["enable_pg_native_login"] = enable_pg_native_login
            __props__.__dict__["enable_readable_secondaries"] = enable_readable_secondaries
            __props__.__dict__["name"] = name
            __props__.__dict__["node_count"] = node_count
            __props__.__dict__["parent_instance_ref"] = parent_instance_ref
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["purge_on_delete"] = purge_on_delete
            __props__.__dict__["retention_window_in_days"] = retention_window_in_days
            __props__.__dict__["stopped"] = stopped
            __props__.__dict__["usage_policy_id"] = usage_policy_id
            __props__.__dict__["child_instance_refs"] = None
            __props__.__dict__["creation_time"] = None
            __props__.__dict__["creator"] = None
            __props__.__dict__["effective_capacity"] = None
            __props__.__dict__["effective_custom_tags"] = None
            __props__.__dict__["effective_enable_pg_native_login"] = None
            __props__.__dict__["effective_enable_readable_secondaries"] = None
            __props__.__dict__["effective_node_count"] = None
            __props__.__dict__["effective_retention_window_in_days"] = None
            __props__.__dict__["effective_stopped"] = None
            __props__.__dict__["effective_usage_policy_id"] = None
            __props__.__dict__["pg_version"] = None
            __props__.__dict__["read_only_dns"] = None
            __props__.__dict__["read_write_dns"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["uid"] = None
        super(DatabaseInstance, __self__).__init__(
            'databricks:index/databaseInstance:DatabaseInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacity: Optional[pulumi.Input[_builtins.str]] = None,
            child_instance_refs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceChildInstanceRefArgs', 'DatabaseInstanceChildInstanceRefArgsDict']]]]] = None,
            creation_time: Optional[pulumi.Input[_builtins.str]] = None,
            creator: Optional[pulumi.Input[_builtins.str]] = None,
            custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]]] = None,
            effective_capacity: Optional[pulumi.Input[_builtins.str]] = None,
            effective_custom_tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceEffectiveCustomTagArgs', 'DatabaseInstanceEffectiveCustomTagArgsDict']]]]] = None,
            effective_enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
            effective_enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
            effective_node_count: Optional[pulumi.Input[_builtins.int]] = None,
            effective_retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
            effective_stopped: Optional[pulumi.Input[_builtins.bool]] = None,
            effective_usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            enable_pg_native_login: Optional[pulumi.Input[_builtins.bool]] = None,
            enable_readable_secondaries: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            node_count: Optional[pulumi.Input[_builtins.int]] = None,
            parent_instance_ref: Optional[pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']]] = None,
            pg_version: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['DatabaseInstanceProviderConfigArgs', 'DatabaseInstanceProviderConfigArgsDict']]] = None,
            purge_on_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            read_only_dns: Optional[pulumi.Input[_builtins.str]] = None,
            read_write_dns: Optional[pulumi.Input[_builtins.str]] = None,
            retention_window_in_days: Optional[pulumi.Input[_builtins.int]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            stopped: Optional[pulumi.Input[_builtins.bool]] = None,
            uid: Optional[pulumi.Input[_builtins.str]] = None,
            usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'DatabaseInstance':
        """
        Get an existing DatabaseInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] capacity: The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceChildInstanceRefArgs', 'DatabaseInstanceChildInstanceRefArgsDict']]]] child_instance_refs: (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
               parent instance
        :param pulumi.Input[_builtins.str] creation_time: (string) - The timestamp when the instance was created
        :param pulumi.Input[_builtins.str] creator: (string) - The email of the creator of the instance
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceCustomTagArgs', 'DatabaseInstanceCustomTagArgsDict']]]] custom_tags: Custom tags associated with the instance. This field is only included on create and update responses
        :param pulumi.Input[_builtins.str] effective_capacity: (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseInstanceEffectiveCustomTagArgs', 'DatabaseInstanceEffectiveCustomTagArgsDict']]]] effective_custom_tags: (list of CustomTag) - The recorded custom tags associated with the instance.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.bool] effective_enable_pg_native_login: (boolean) - Whether the instance has PG native password login enabled.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.bool] effective_enable_readable_secondaries: (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.int] effective_node_count: (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.int] effective_retention_window_in_days: (integer) - The retention window for the instance. This is the time window in days
               for which the historical data is retained.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.bool] effective_stopped: (boolean) - Whether the instance is stopped.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.str] effective_usage_policy_id: (string) - The policy that is applied to the instance.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.bool] enable_pg_native_login: Whether to enable PG native password login on the instance. Defaults to false
        :param pulumi.Input[_builtins.bool] enable_readable_secondaries: Whether to enable secondaries to serve read-only traffic. Defaults to false
        :param pulumi.Input[_builtins.str] name: The name of the instance. This is the unique identifier for the instance
        :param pulumi.Input[_builtins.int] node_count: The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
               1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        :param pulumi.Input[Union['DatabaseInstanceParentInstanceRefArgs', 'DatabaseInstanceParentInstanceRefArgsDict']] parent_instance_ref: The ref of the parent instance. This is only available if the instance is
               child instance.
               Input: For specifying the parent instance to create a child instance. Optional.
               Output: Only populated if provided as input to create a child instance
        :param pulumi.Input[_builtins.str] pg_version: (string) - The version of Postgres running on the instance
        :param pulumi.Input[Union['DatabaseInstanceProviderConfigArgs', 'DatabaseInstanceProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.bool] purge_on_delete: Purge the resource on delete
        :param pulumi.Input[_builtins.str] read_only_dns: (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
               enable_readable_secondaries is true
        :param pulumi.Input[_builtins.str] read_write_dns: (string) - The DNS endpoint to connect to the instance for read+write access
        :param pulumi.Input[_builtins.int] retention_window_in_days: The retention window for the instance. This is the time window in days
               for which the historical data is retained. The default value is 7 days.
               Valid values are 2 to 35 days
        :param pulumi.Input[_builtins.str] state: (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        :param pulumi.Input[_builtins.bool] stopped: Whether to stop the instance. An input only param, see effective_stopped for the output
        :param pulumi.Input[_builtins.str] uid: (string) - Id of the ref database instance
        :param pulumi.Input[_builtins.str] usage_policy_id: The desired usage policy to associate with the instance
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseInstanceState.__new__(_DatabaseInstanceState)

        __props__.__dict__["capacity"] = capacity
        __props__.__dict__["child_instance_refs"] = child_instance_refs
        __props__.__dict__["creation_time"] = creation_time
        __props__.__dict__["creator"] = creator
        __props__.__dict__["custom_tags"] = custom_tags
        __props__.__dict__["effective_capacity"] = effective_capacity
        __props__.__dict__["effective_custom_tags"] = effective_custom_tags
        __props__.__dict__["effective_enable_pg_native_login"] = effective_enable_pg_native_login
        __props__.__dict__["effective_enable_readable_secondaries"] = effective_enable_readable_secondaries
        __props__.__dict__["effective_node_count"] = effective_node_count
        __props__.__dict__["effective_retention_window_in_days"] = effective_retention_window_in_days
        __props__.__dict__["effective_stopped"] = effective_stopped
        __props__.__dict__["effective_usage_policy_id"] = effective_usage_policy_id
        __props__.__dict__["enable_pg_native_login"] = enable_pg_native_login
        __props__.__dict__["enable_readable_secondaries"] = enable_readable_secondaries
        __props__.__dict__["name"] = name
        __props__.__dict__["node_count"] = node_count
        __props__.__dict__["parent_instance_ref"] = parent_instance_ref
        __props__.__dict__["pg_version"] = pg_version
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["purge_on_delete"] = purge_on_delete
        __props__.__dict__["read_only_dns"] = read_only_dns
        __props__.__dict__["read_write_dns"] = read_write_dns
        __props__.__dict__["retention_window_in_days"] = retention_window_in_days
        __props__.__dict__["state"] = state
        __props__.__dict__["stopped"] = stopped
        __props__.__dict__["uid"] = uid
        __props__.__dict__["usage_policy_id"] = usage_policy_id
        return DatabaseInstance(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def capacity(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The sku of the instance. Valid values are "CU_1", "CU_2", "CU_4", "CU_8"
        """
        return pulumi.get(self, "capacity")

    @_builtins.property
    @pulumi.getter(name="childInstanceRefs")
    def child_instance_refs(self) -> pulumi.Output[Sequence['outputs.DatabaseInstanceChildInstanceRef']]:
        """
        (list of DatabaseInstanceRef) - The refs of the child instances. This is only available if the instance is
        parent instance
        """
        return pulumi.get(self, "child_instance_refs")

    @_builtins.property
    @pulumi.getter(name="creationTime")
    def creation_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The timestamp when the instance was created
        """
        return pulumi.get(self, "creation_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The email of the creator of the instance
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter(name="customTags")
    def custom_tags(self) -> pulumi.Output[Sequence['outputs.DatabaseInstanceCustomTag']]:
        """
        Custom tags associated with the instance. This field is only included on create and update responses
        """
        return pulumi.get(self, "custom_tags")

    @_builtins.property
    @pulumi.getter(name="effectiveCapacity")
    def effective_capacity(self) -> pulumi.Output[_builtins.str]:
        """
        (string, deprecated) - Deprecated. The sku of the instance; this field will always match the value of capacity.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_capacity")

    @_builtins.property
    @pulumi.getter(name="effectiveCustomTags")
    def effective_custom_tags(self) -> pulumi.Output[Sequence['outputs.DatabaseInstanceEffectiveCustomTag']]:
        """
        (list of CustomTag) - The recorded custom tags associated with the instance.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_custom_tags")

    @_builtins.property
    @pulumi.getter(name="effectiveEnablePgNativeLogin")
    def effective_enable_pg_native_login(self) -> pulumi.Output[_builtins.bool]:
        """
        (boolean) - Whether the instance has PG native password login enabled.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_enable_pg_native_login")

    @_builtins.property
    @pulumi.getter(name="effectiveEnableReadableSecondaries")
    def effective_enable_readable_secondaries(self) -> pulumi.Output[_builtins.bool]:
        """
        (boolean) - Whether secondaries serving read-only traffic are enabled. Defaults to false.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_enable_readable_secondaries")

    @_builtins.property
    @pulumi.getter(name="effectiveNodeCount")
    def effective_node_count(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_node_count")

    @_builtins.property
    @pulumi.getter(name="effectiveRetentionWindowInDays")
    def effective_retention_window_in_days(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - The retention window for the instance. This is the time window in days
        for which the historical data is retained.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_retention_window_in_days")

    @_builtins.property
    @pulumi.getter(name="effectiveStopped")
    def effective_stopped(self) -> pulumi.Output[_builtins.bool]:
        """
        (boolean) - Whether the instance is stopped.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_stopped")

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The policy that is applied to the instance.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="enablePgNativeLogin")
    def enable_pg_native_login(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to enable PG native password login on the instance. Defaults to false
        """
        return pulumi.get(self, "enable_pg_native_login")

    @_builtins.property
    @pulumi.getter(name="enableReadableSecondaries")
    def enable_readable_secondaries(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to enable secondaries to serve read-only traffic. Defaults to false
        """
        return pulumi.get(self, "enable_readable_secondaries")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the instance. This is the unique identifier for the instance
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> pulumi.Output[_builtins.int]:
        """
        The number of nodes in the instance, composed of 1 primary and 0 or more secondaries. Defaults to
        1 primary and 0 secondaries. This field is input only, see effective_node_count for the output
        """
        return pulumi.get(self, "node_count")

    @_builtins.property
    @pulumi.getter(name="parentInstanceRef")
    def parent_instance_ref(self) -> pulumi.Output[Optional['outputs.DatabaseInstanceParentInstanceRef']]:
        """
        The ref of the parent instance. This is only available if the instance is
        child instance.
        Input: For specifying the parent instance to create a child instance. Optional.
        Output: Only populated if provided as input to create a child instance
        """
        return pulumi.get(self, "parent_instance_ref")

    @_builtins.property
    @pulumi.getter(name="pgVersion")
    def pg_version(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The version of Postgres running on the instance
        """
        return pulumi.get(self, "pg_version")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.DatabaseInstanceProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="purgeOnDelete")
    def purge_on_delete(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Purge the resource on delete
        """
        return pulumi.get(self, "purge_on_delete")

    @_builtins.property
    @pulumi.getter(name="readOnlyDns")
    def read_only_dns(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The DNS endpoint to connect to the instance for read only access. This is only available if
        enable_readable_secondaries is true
        """
        return pulumi.get(self, "read_only_dns")

    @_builtins.property
    @pulumi.getter(name="readWriteDns")
    def read_write_dns(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The DNS endpoint to connect to the instance for read+write access
        """
        return pulumi.get(self, "read_write_dns")

    @_builtins.property
    @pulumi.getter(name="retentionWindowInDays")
    def retention_window_in_days(self) -> pulumi.Output[_builtins.int]:
        """
        The retention window for the instance. This is the time window in days
        for which the historical data is retained. The default value is 7 days.
        Valid values are 2 to 35 days
        """
        return pulumi.get(self, "retention_window_in_days")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The current state of the instance. Possible values are: `AVAILABLE`, `DELETING`, `FAILING_OVER`, `STARTING`, `STOPPED`, `UPDATING`
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def stopped(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to stop the instance. An input only param, see effective_stopped for the output
        """
        return pulumi.get(self, "stopped")

    @_builtins.property
    @pulumi.getter
    def uid(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Id of the ref database instance
        """
        return pulumi.get(self, "uid")

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        The desired usage policy to associate with the instance
        """
        return pulumi.get(self, "usage_policy_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetQualityMonitorsV2Result',
    'AwaitableGetQualityMonitorsV2Result',
    'get_quality_monitors_v2',
    'get_quality_monitors_v2_output',
]

@pulumi.output_type
class GetQualityMonitorsV2Result:
    """
    A collection of values returned by getQualityMonitorsV2.
    """
    def __init__(__self__, id=None, page_size=None, provider_config=None, quality_monitors=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if quality_monitors and not isinstance(quality_monitors, list):
            raise TypeError("Expected argument 'quality_monitors' to be a list")
        pulumi.set(__self__, "quality_monitors", quality_monitors)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetQualityMonitorsV2ProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="qualityMonitors")
    def quality_monitors(self) -> Sequence['outputs.GetQualityMonitorsV2QualityMonitorResult']:
        return pulumi.get(self, "quality_monitors")


class AwaitableGetQualityMonitorsV2Result(GetQualityMonitorsV2Result):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetQualityMonitorsV2Result(
            id=self.id,
            page_size=self.page_size,
            provider_config=self.provider_config,
            quality_monitors=self.quality_monitors)


def get_quality_monitors_v2(page_size: Optional[_builtins.int] = None,
                            provider_config: Optional[Union['GetQualityMonitorsV2ProviderConfigArgs', 'GetQualityMonitorsV2ProviderConfigArgsDict']] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetQualityMonitorsV2Result:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    > **Deprecated** This data source is deprecated. Please use `get_data_quality_monitors` instead.

    This data source can be used to fetch the list of quality monitors v2.

    > **Note** This data source can only be used with an workspace-level provider!

    ## Example Usage

    > **Deprecated** This data source is deprecated. Please use `get_data_quality_monitors` instead.

    Getting a list of all quality monitors:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_quality_monitors_v2()
    ```


    :param Union['GetQualityMonitorsV2ProviderConfigArgs', 'GetQualityMonitorsV2ProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getQualityMonitorsV2:getQualityMonitorsV2', __args__, opts=opts, typ=GetQualityMonitorsV2Result).value

    return AwaitableGetQualityMonitorsV2Result(
        id=pulumi.get(__ret__, 'id'),
        page_size=pulumi.get(__ret__, 'page_size'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        quality_monitors=pulumi.get(__ret__, 'quality_monitors'))
def get_quality_monitors_v2_output(page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                   provider_config: Optional[pulumi.Input[Optional[Union['GetQualityMonitorsV2ProviderConfigArgs', 'GetQualityMonitorsV2ProviderConfigArgsDict']]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetQualityMonitorsV2Result]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    > **Deprecated** This data source is deprecated. Please use `get_data_quality_monitors` instead.

    This data source can be used to fetch the list of quality monitors v2.

    > **Note** This data source can only be used with an workspace-level provider!

    ## Example Usage

    > **Deprecated** This data source is deprecated. Please use `get_data_quality_monitors` instead.

    Getting a list of all quality monitors:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_quality_monitors_v2()
    ```


    :param Union['GetQualityMonitorsV2ProviderConfigArgs', 'GetQualityMonitorsV2ProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getQualityMonitorsV2:getQualityMonitorsV2', __args__, opts=opts, typ=GetQualityMonitorsV2Result)
    return __ret__.apply(lambda __response__: GetQualityMonitorsV2Result(
        id=pulumi.get(__response__, 'id'),
        page_size=pulumi.get(__response__, 'page_size'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        quality_monitors=pulumi.get(__response__, 'quality_monitors')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AccountNetworkPolicyArgs', 'AccountNetworkPolicy']

@pulumi.input_type
class AccountNetworkPolicyArgs:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 egress: Optional[pulumi.Input['AccountNetworkPolicyEgressArgs']] = None,
                 network_policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AccountNetworkPolicy resource.
        :param pulumi.Input[_builtins.str] account_id: The associated account ID for this Network Policy object
        :param pulumi.Input['AccountNetworkPolicyEgressArgs'] egress: The network policies applying for egress traffic
        :param pulumi.Input[_builtins.str] network_policy_id: The unique identifier for the network policy
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if egress is not None:
            pulumi.set(__self__, "egress", egress)
        if network_policy_id is not None:
            pulumi.set(__self__, "network_policy_id", network_policy_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The associated account ID for this Network Policy object
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def egress(self) -> Optional[pulumi.Input['AccountNetworkPolicyEgressArgs']]:
        """
        The network policies applying for egress traffic
        """
        return pulumi.get(self, "egress")

    @egress.setter
    def egress(self, value: Optional[pulumi.Input['AccountNetworkPolicyEgressArgs']]):
        pulumi.set(self, "egress", value)

    @_builtins.property
    @pulumi.getter(name="networkPolicyId")
    def network_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier for the network policy
        """
        return pulumi.get(self, "network_policy_id")

    @network_policy_id.setter
    def network_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_policy_id", value)


@pulumi.input_type
class _AccountNetworkPolicyState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 egress: Optional[pulumi.Input['AccountNetworkPolicyEgressArgs']] = None,
                 network_policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AccountNetworkPolicy resources.
        :param pulumi.Input[_builtins.str] account_id: The associated account ID for this Network Policy object
        :param pulumi.Input['AccountNetworkPolicyEgressArgs'] egress: The network policies applying for egress traffic
        :param pulumi.Input[_builtins.str] network_policy_id: The unique identifier for the network policy
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if egress is not None:
            pulumi.set(__self__, "egress", egress)
        if network_policy_id is not None:
            pulumi.set(__self__, "network_policy_id", network_policy_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The associated account ID for this Network Policy object
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def egress(self) -> Optional[pulumi.Input['AccountNetworkPolicyEgressArgs']]:
        """
        The network policies applying for egress traffic
        """
        return pulumi.get(self, "egress")

    @egress.setter
    def egress(self, value: Optional[pulumi.Input['AccountNetworkPolicyEgressArgs']]):
        pulumi.set(self, "egress", value)

    @_builtins.property
    @pulumi.getter(name="networkPolicyId")
    def network_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier for the network policy
        """
        return pulumi.get(self, "network_policy_id")

    @network_policy_id.setter
    def network_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_policy_id", value)


@pulumi.type_token("databricks:index/accountNetworkPolicy:AccountNetworkPolicy")
class AccountNetworkPolicy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 egress: Optional[pulumi.Input[Union['AccountNetworkPolicyEgressArgs', 'AccountNetworkPolicyEgressArgsDict']]] = None,
                 network_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Network policies control which network destinations can be accessed from the Databricks environment.

        Each Databricks account includes a default policy named `default-policy`. This policy is:

        - Associated with any workspace lacking an explicit network policy assignment
        - Automatically associated with each newly created workspace
        - Reserved and cannot be deleted, but can be updated to customize the default network access rules for your account

        The `default-policy` provides a baseline security configuration that ensures all workspaces have network access controls in place.

        > **Note** This resource can only be used with an account-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        example_network_policy = databricks.AccountNetworkPolicy("example_network_policy",
            network_policy_id="example-network-policy",
            egress={
                "network_access": {
                    "restriction_mode": "RESTRICTED_ACCESS",
                    "allowed_internet_destinations": [{
                        "destination": "example.com",
                        "internet_destination_type": "DNS_NAME",
                    }],
                    "allowed_storage_destinations": [{
                        "bucket_name": "example-aws-cloud-storage",
                        "region": "us-west-1",
                        "storage_destination_type": "AWS_S3",
                    }],
                    "policy_enforcement": {
                        "enforcement_mode": "ENFORCED",
                    },
                },
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The associated account ID for this Network Policy object
        :param pulumi.Input[Union['AccountNetworkPolicyEgressArgs', 'AccountNetworkPolicyEgressArgsDict']] egress: The network policies applying for egress traffic
        :param pulumi.Input[_builtins.str] network_policy_id: The unique identifier for the network policy
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AccountNetworkPolicyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Network policies control which network destinations can be accessed from the Databricks environment.

        Each Databricks account includes a default policy named `default-policy`. This policy is:

        - Associated with any workspace lacking an explicit network policy assignment
        - Automatically associated with each newly created workspace
        - Reserved and cannot be deleted, but can be updated to customize the default network access rules for your account

        The `default-policy` provides a baseline security configuration that ensures all workspaces have network access controls in place.

        > **Note** This resource can only be used with an account-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        example_network_policy = databricks.AccountNetworkPolicy("example_network_policy",
            network_policy_id="example-network-policy",
            egress={
                "network_access": {
                    "restriction_mode": "RESTRICTED_ACCESS",
                    "allowed_internet_destinations": [{
                        "destination": "example.com",
                        "internet_destination_type": "DNS_NAME",
                    }],
                    "allowed_storage_destinations": [{
                        "bucket_name": "example-aws-cloud-storage",
                        "region": "us-west-1",
                        "storage_destination_type": "AWS_S3",
                    }],
                    "policy_enforcement": {
                        "enforcement_mode": "ENFORCED",
                    },
                },
            })
        ```

        :param str resource_name: The name of the resource.
        :param AccountNetworkPolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountNetworkPolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 egress: Optional[pulumi.Input[Union['AccountNetworkPolicyEgressArgs', 'AccountNetworkPolicyEgressArgsDict']]] = None,
                 network_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountNetworkPolicyArgs.__new__(AccountNetworkPolicyArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["egress"] = egress
            __props__.__dict__["network_policy_id"] = network_policy_id
        super(AccountNetworkPolicy, __self__).__init__(
            'databricks:index/accountNetworkPolicy:AccountNetworkPolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            egress: Optional[pulumi.Input[Union['AccountNetworkPolicyEgressArgs', 'AccountNetworkPolicyEgressArgsDict']]] = None,
            network_policy_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'AccountNetworkPolicy':
        """
        Get an existing AccountNetworkPolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The associated account ID for this Network Policy object
        :param pulumi.Input[Union['AccountNetworkPolicyEgressArgs', 'AccountNetworkPolicyEgressArgsDict']] egress: The network policies applying for egress traffic
        :param pulumi.Input[_builtins.str] network_policy_id: The unique identifier for the network policy
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountNetworkPolicyState.__new__(_AccountNetworkPolicyState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["egress"] = egress
        __props__.__dict__["network_policy_id"] = network_policy_id
        return AccountNetworkPolicy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The associated account ID for this Network Policy object
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def egress(self) -> pulumi.Output[Optional['outputs.AccountNetworkPolicyEgress']]:
        """
        The network policies applying for egress traffic
        """
        return pulumi.get(self, "egress")

    @_builtins.property
    @pulumi.getter(name="networkPolicyId")
    def network_policy_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The unique identifier for the network policy
        """
        return pulumi.get(self, "network_policy_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatabaseSyncedDatabaseTableArgs', 'DatabaseSyncedDatabaseTable']

@pulumi.input_type
class DatabaseSyncedDatabaseTableArgs:
    def __init__(__self__, *,
                 database_instance_name: Optional[pulumi.Input[_builtins.str]] = None,
                 logical_database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['DatabaseSyncedDatabaseTableProviderConfigArgs']] = None,
                 spec: Optional[pulumi.Input['DatabaseSyncedDatabaseTableSpecArgs']] = None):
        """
        The set of arguments for constructing a DatabaseSyncedDatabaseTable resource.
        :param pulumi.Input[_builtins.str] database_instance_name: Name of the target database instance. This is required when creating synced database tables in standard catalogs.
               This is optional when creating synced database tables in registered catalogs. If this field is specified
               when creating synced database tables in registered catalogs, the database instance name MUST
               match that of the registered catalog (or the request will be rejected)
        :param pulumi.Input[_builtins.str] logical_database_name: Target Postgres database object (logical database) name for this table.
               
               When creating a synced table in a registered Postgres catalog, the
               target Postgres database name is inferred to be that of the registered catalog.
               If this field is specified in this scenario, the Postgres database name MUST
               match that of the registered catalog (or the request will be rejected).
               
               When creating a synced table in a standard catalog, this field is required.
               In this scenario, specifying this field will allow targeting an arbitrary postgres database.
               Note that this has implications for the `create_database_objects_is_missing` field in `spec`
        :param pulumi.Input[_builtins.str] name: Full three-part (catalog, schema, table) name of the table
        :param pulumi.Input['DatabaseSyncedDatabaseTableProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        if database_instance_name is not None:
            pulumi.set(__self__, "database_instance_name", database_instance_name)
        if logical_database_name is not None:
            pulumi.set(__self__, "logical_database_name", logical_database_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)

    @_builtins.property
    @pulumi.getter(name="databaseInstanceName")
    def database_instance_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the target database instance. This is required when creating synced database tables in standard catalogs.
        This is optional when creating synced database tables in registered catalogs. If this field is specified
        when creating synced database tables in registered catalogs, the database instance name MUST
        match that of the registered catalog (or the request will be rejected)
        """
        return pulumi.get(self, "database_instance_name")

    @database_instance_name.setter
    def database_instance_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "database_instance_name", value)

    @_builtins.property
    @pulumi.getter(name="logicalDatabaseName")
    def logical_database_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Target Postgres database object (logical database) name for this table.

        When creating a synced table in a registered Postgres catalog, the
        target Postgres database name is inferred to be that of the registered catalog.
        If this field is specified in this scenario, the Postgres database name MUST
        match that of the registered catalog (or the request will be rejected).

        When creating a synced table in a standard catalog, this field is required.
        In this scenario, specifying this field will allow targeting an arbitrary postgres database.
        Note that this has implications for the `create_database_objects_is_missing` field in `spec`
        """
        return pulumi.get(self, "logical_database_name")

    @logical_database_name.setter
    def logical_database_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logical_database_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Full three-part (catalog, schema, table) name of the table
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DatabaseSyncedDatabaseTableProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DatabaseSyncedDatabaseTableProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['DatabaseSyncedDatabaseTableSpecArgs']]:
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['DatabaseSyncedDatabaseTableSpecArgs']]):
        pulumi.set(self, "spec", value)


@pulumi.input_type
class _DatabaseSyncedDatabaseTableState:
    def __init__(__self__, *,
                 data_synchronization_status: Optional[pulumi.Input['DatabaseSyncedDatabaseTableDataSynchronizationStatusArgs']] = None,
                 database_instance_name: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_database_instance_name: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_logical_database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 logical_database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['DatabaseSyncedDatabaseTableProviderConfigArgs']] = None,
                 spec: Optional[pulumi.Input['DatabaseSyncedDatabaseTableSpecArgs']] = None,
                 unity_catalog_provisioning_state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DatabaseSyncedDatabaseTable resources.
        :param pulumi.Input['DatabaseSyncedDatabaseTableDataSynchronizationStatusArgs'] data_synchronization_status: (SyncedTableStatus) - Synced Table data synchronization status
        :param pulumi.Input[_builtins.str] database_instance_name: Name of the target database instance. This is required when creating synced database tables in standard catalogs.
               This is optional when creating synced database tables in registered catalogs. If this field is specified
               when creating synced database tables in registered catalogs, the database instance name MUST
               match that of the registered catalog (or the request will be rejected)
        :param pulumi.Input[_builtins.str] effective_database_instance_name: (string) - The name of the database instance that this table is registered to. This field is always returned, and for
               tables inside database catalogs is inferred database instance associated with the catalog.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.str] effective_logical_database_name: (string) - The name of the logical database that this table is registered to.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.str] logical_database_name: Target Postgres database object (logical database) name for this table.
               
               When creating a synced table in a registered Postgres catalog, the
               target Postgres database name is inferred to be that of the registered catalog.
               If this field is specified in this scenario, the Postgres database name MUST
               match that of the registered catalog (or the request will be rejected).
               
               When creating a synced table in a standard catalog, this field is required.
               In this scenario, specifying this field will allow targeting an arbitrary postgres database.
               Note that this has implications for the `create_database_objects_is_missing` field in `spec`
        :param pulumi.Input[_builtins.str] name: Full three-part (catalog, schema, table) name of the table
        :param pulumi.Input['DatabaseSyncedDatabaseTableProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] unity_catalog_provisioning_state: (string) - The provisioning state of the synced table entity in Unity Catalog. This is distinct from the
               state of the data synchronization pipeline (i.e. the table may be in "ACTIVE" but the pipeline
               may be in "PROVISIONING" as it runs asynchronously). Possible values are: `ACTIVE`, `DEGRADED`, `DELETING`, `FAILED`, `PROVISIONING`, `UPDATING`
        """
        if data_synchronization_status is not None:
            pulumi.set(__self__, "data_synchronization_status", data_synchronization_status)
        if database_instance_name is not None:
            pulumi.set(__self__, "database_instance_name", database_instance_name)
        if effective_database_instance_name is not None:
            pulumi.set(__self__, "effective_database_instance_name", effective_database_instance_name)
        if effective_logical_database_name is not None:
            pulumi.set(__self__, "effective_logical_database_name", effective_logical_database_name)
        if logical_database_name is not None:
            pulumi.set(__self__, "logical_database_name", logical_database_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if unity_catalog_provisioning_state is not None:
            pulumi.set(__self__, "unity_catalog_provisioning_state", unity_catalog_provisioning_state)

    @_builtins.property
    @pulumi.getter(name="dataSynchronizationStatus")
    def data_synchronization_status(self) -> Optional[pulumi.Input['DatabaseSyncedDatabaseTableDataSynchronizationStatusArgs']]:
        """
        (SyncedTableStatus) - Synced Table data synchronization status
        """
        return pulumi.get(self, "data_synchronization_status")

    @data_synchronization_status.setter
    def data_synchronization_status(self, value: Optional[pulumi.Input['DatabaseSyncedDatabaseTableDataSynchronizationStatusArgs']]):
        pulumi.set(self, "data_synchronization_status", value)

    @_builtins.property
    @pulumi.getter(name="databaseInstanceName")
    def database_instance_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the target database instance. This is required when creating synced database tables in standard catalogs.
        This is optional when creating synced database tables in registered catalogs. If this field is specified
        when creating synced database tables in registered catalogs, the database instance name MUST
        match that of the registered catalog (or the request will be rejected)
        """
        return pulumi.get(self, "database_instance_name")

    @database_instance_name.setter
    def database_instance_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "database_instance_name", value)

    @_builtins.property
    @pulumi.getter(name="effectiveDatabaseInstanceName")
    def effective_database_instance_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The name of the database instance that this table is registered to. This field is always returned, and for
        tables inside database catalogs is inferred database instance associated with the catalog.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_database_instance_name")

    @effective_database_instance_name.setter
    def effective_database_instance_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_database_instance_name", value)

    @_builtins.property
    @pulumi.getter(name="effectiveLogicalDatabaseName")
    def effective_logical_database_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The name of the logical database that this table is registered to.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_logical_database_name")

    @effective_logical_database_name.setter
    def effective_logical_database_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_logical_database_name", value)

    @_builtins.property
    @pulumi.getter(name="logicalDatabaseName")
    def logical_database_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Target Postgres database object (logical database) name for this table.

        When creating a synced table in a registered Postgres catalog, the
        target Postgres database name is inferred to be that of the registered catalog.
        If this field is specified in this scenario, the Postgres database name MUST
        match that of the registered catalog (or the request will be rejected).

        When creating a synced table in a standard catalog, this field is required.
        In this scenario, specifying this field will allow targeting an arbitrary postgres database.
        Note that this has implications for the `create_database_objects_is_missing` field in `spec`
        """
        return pulumi.get(self, "logical_database_name")

    @logical_database_name.setter
    def logical_database_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "logical_database_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Full three-part (catalog, schema, table) name of the table
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['DatabaseSyncedDatabaseTableProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['DatabaseSyncedDatabaseTableProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input['DatabaseSyncedDatabaseTableSpecArgs']]:
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input['DatabaseSyncedDatabaseTableSpecArgs']]):
        pulumi.set(self, "spec", value)

    @_builtins.property
    @pulumi.getter(name="unityCatalogProvisioningState")
    def unity_catalog_provisioning_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The provisioning state of the synced table entity in Unity Catalog. This is distinct from the
        state of the data synchronization pipeline (i.e. the table may be in "ACTIVE" but the pipeline
        may be in "PROVISIONING" as it runs asynchronously). Possible values are: `ACTIVE`, `DEGRADED`, `DELETING`, `FAILED`, `PROVISIONING`, `UPDATING`
        """
        return pulumi.get(self, "unity_catalog_provisioning_state")

    @unity_catalog_provisioning_state.setter
    def unity_catalog_provisioning_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "unity_catalog_provisioning_state", value)


@pulumi.type_token("databricks:index/databaseSyncedDatabaseTable:DatabaseSyncedDatabaseTable")
class DatabaseSyncedDatabaseTable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database_instance_name: Optional[pulumi.Input[_builtins.str]] = None,
                 logical_database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['DatabaseSyncedDatabaseTableProviderConfigArgs', 'DatabaseSyncedDatabaseTableProviderConfigArgsDict']]] = None,
                 spec: Optional[pulumi.Input[Union['DatabaseSyncedDatabaseTableSpecArgs', 'DatabaseSyncedDatabaseTableSpecArgsDict']]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Lakebase Synced Database Tables are Postgres tables automatically synced from a source table inside Unity Catalog.
        They can be used to serve realtime queries without the operational overhead of managing ETL pipelines.

        Synced Database Tables can be configured inside either Database Catalogs or Standard Catalogs. Multiple
        Synced Database Tables can be bin packed inside a single pipeline to optimize costs.

        ## Example Usage

        ### Creating a Synced Database Table inside a Database Catalog

        This example creates a Synced Database Table inside a Database Catalog.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseSyncedDatabaseTable("this",
            name="my_database_catalog.public.synced_table",
            logical_database_name="databricks_postgres",
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.tpch.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "new_pipeline_spec": {
                    "storage_catalog": "source_delta",
                    "storage_schema": "tpch",
                },
            })
        ```

        ### Creating a Synced Database Table inside a Standard Catalog

        This example creates a Synced Database Table inside a Standard Catalog.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseSyncedDatabaseTable("this",
            name="my_standard_catalog.public.synced_table",
            logical_database_name="databricks_postgres",
            database_instance_name="my-database-instance",
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.tpch.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "new_pipeline_spec": {
                    "storage_catalog": "source_delta",
                    "storage_schema": "tpch",
                },
            })
        ```

        ### Creating multiple Synced Database Tables and bin packing them into a single pipeline

        This example creates two Synced Database Tables. The first one specifies a new pipeline spec,
        which generates a new pipeline. The second one utilizes the pipeline ID of the first table.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        instance = databricks.DatabaseInstance("instance",
            name="my-database-instance",
            capacity="CU_1")
        synced_table1 = databricks.DatabaseSyncedDatabaseTable("synced_table_1",
            name="my_standard_catalog.public.synced_table1",
            logical_database_name="databricks_postgres",
            database_instance_name=instance.name,
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.tpch.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "new_pipeline_spec": {
                    "storage_catalog": "source_delta",
                    "storage_schema": "tpch",
                },
            })
        synced_table2 = databricks.DatabaseSyncedDatabaseTable("synced_table_2",
            name="my_standard_catalog.public.synced_table2",
            logical_database_name="databricks_postgres",
            database_instance_name=instance.name,
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.tpch.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "existing_pipeline_id": synced_table1.data_synchronization_status.pipeline_id,
            })
        ```

        ### Creating a Synced Database Table with a custom Jobs schedule

        This example creates a Synced Database Table and customizes the pipeline schedule. It assumes you already have

        - A database instance named `"my-database-instance"`
        - A standard catalog named `"my_standard_catalog"`
        - A schema in the standard catalog named `"default"`
        - A source delta table named `"source_delta.schema.customer"` with the primary key `"c_custkey"`

        ```python
        import pulumi
        import pulumi_databricks as databricks

        synced_table = databricks.DatabaseSyncedDatabaseTable("synced_table",
            name="my_standard_catalog.default.my_synced_table",
            logical_database_name="terraform_test_db",
            database_instance_name="my-database-instance",
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.schema.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "new_pipeline_spec": {
                    "storage_catalog": "source_delta",
                    "storage_schema": "schema",
                },
            })
        sync_pipeline_schedule_job = databricks.Job("sync_pipeline_schedule_job",
            name="Synced Pipeline Refresh",
            description="Job to schedule synced database table pipeline. ",
            tasks=[{
                "task_key": "synced-table-pipeline",
                "pipeline_task": {
                    "pipeline_id": synced_table.data_synchronization_status.pipeline_id,
                },
            }],
            schedule={
                "quartz_cron_expression": "0 0 0 * * ?",
                "timezone_id": "Europe/Helsinki",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] database_instance_name: Name of the target database instance. This is required when creating synced database tables in standard catalogs.
               This is optional when creating synced database tables in registered catalogs. If this field is specified
               when creating synced database tables in registered catalogs, the database instance name MUST
               match that of the registered catalog (or the request will be rejected)
        :param pulumi.Input[_builtins.str] logical_database_name: Target Postgres database object (logical database) name for this table.
               
               When creating a synced table in a registered Postgres catalog, the
               target Postgres database name is inferred to be that of the registered catalog.
               If this field is specified in this scenario, the Postgres database name MUST
               match that of the registered catalog (or the request will be rejected).
               
               When creating a synced table in a standard catalog, this field is required.
               In this scenario, specifying this field will allow targeting an arbitrary postgres database.
               Note that this has implications for the `create_database_objects_is_missing` field in `spec`
        :param pulumi.Input[_builtins.str] name: Full three-part (catalog, schema, table) name of the table
        :param pulumi.Input[Union['DatabaseSyncedDatabaseTableProviderConfigArgs', 'DatabaseSyncedDatabaseTableProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[DatabaseSyncedDatabaseTableArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Lakebase Synced Database Tables are Postgres tables automatically synced from a source table inside Unity Catalog.
        They can be used to serve realtime queries without the operational overhead of managing ETL pipelines.

        Synced Database Tables can be configured inside either Database Catalogs or Standard Catalogs. Multiple
        Synced Database Tables can be bin packed inside a single pipeline to optimize costs.

        ## Example Usage

        ### Creating a Synced Database Table inside a Database Catalog

        This example creates a Synced Database Table inside a Database Catalog.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseSyncedDatabaseTable("this",
            name="my_database_catalog.public.synced_table",
            logical_database_name="databricks_postgres",
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.tpch.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "new_pipeline_spec": {
                    "storage_catalog": "source_delta",
                    "storage_schema": "tpch",
                },
            })
        ```

        ### Creating a Synced Database Table inside a Standard Catalog

        This example creates a Synced Database Table inside a Standard Catalog.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.DatabaseSyncedDatabaseTable("this",
            name="my_standard_catalog.public.synced_table",
            logical_database_name="databricks_postgres",
            database_instance_name="my-database-instance",
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.tpch.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "new_pipeline_spec": {
                    "storage_catalog": "source_delta",
                    "storage_schema": "tpch",
                },
            })
        ```

        ### Creating multiple Synced Database Tables and bin packing them into a single pipeline

        This example creates two Synced Database Tables. The first one specifies a new pipeline spec,
        which generates a new pipeline. The second one utilizes the pipeline ID of the first table.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        instance = databricks.DatabaseInstance("instance",
            name="my-database-instance",
            capacity="CU_1")
        synced_table1 = databricks.DatabaseSyncedDatabaseTable("synced_table_1",
            name="my_standard_catalog.public.synced_table1",
            logical_database_name="databricks_postgres",
            database_instance_name=instance.name,
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.tpch.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "new_pipeline_spec": {
                    "storage_catalog": "source_delta",
                    "storage_schema": "tpch",
                },
            })
        synced_table2 = databricks.DatabaseSyncedDatabaseTable("synced_table_2",
            name="my_standard_catalog.public.synced_table2",
            logical_database_name="databricks_postgres",
            database_instance_name=instance.name,
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.tpch.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "existing_pipeline_id": synced_table1.data_synchronization_status.pipeline_id,
            })
        ```

        ### Creating a Synced Database Table with a custom Jobs schedule

        This example creates a Synced Database Table and customizes the pipeline schedule. It assumes you already have

        - A database instance named `"my-database-instance"`
        - A standard catalog named `"my_standard_catalog"`
        - A schema in the standard catalog named `"default"`
        - A source delta table named `"source_delta.schema.customer"` with the primary key `"c_custkey"`

        ```python
        import pulumi
        import pulumi_databricks as databricks

        synced_table = databricks.DatabaseSyncedDatabaseTable("synced_table",
            name="my_standard_catalog.default.my_synced_table",
            logical_database_name="terraform_test_db",
            database_instance_name="my-database-instance",
            spec={
                "scheduling_policy": "SNAPSHOT",
                "source_table_full_name": "source_delta.schema.customer",
                "primary_key_columns": ["c_custkey"],
                "create_database_objects_if_missing": True,
                "new_pipeline_spec": {
                    "storage_catalog": "source_delta",
                    "storage_schema": "schema",
                },
            })
        sync_pipeline_schedule_job = databricks.Job("sync_pipeline_schedule_job",
            name="Synced Pipeline Refresh",
            description="Job to schedule synced database table pipeline. ",
            tasks=[{
                "task_key": "synced-table-pipeline",
                "pipeline_task": {
                    "pipeline_id": synced_table.data_synchronization_status.pipeline_id,
                },
            }],
            schedule={
                "quartz_cron_expression": "0 0 0 * * ?",
                "timezone_id": "Europe/Helsinki",
            })
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseSyncedDatabaseTableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseSyncedDatabaseTableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 database_instance_name: Optional[pulumi.Input[_builtins.str]] = None,
                 logical_database_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['DatabaseSyncedDatabaseTableProviderConfigArgs', 'DatabaseSyncedDatabaseTableProviderConfigArgsDict']]] = None,
                 spec: Optional[pulumi.Input[Union['DatabaseSyncedDatabaseTableSpecArgs', 'DatabaseSyncedDatabaseTableSpecArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseSyncedDatabaseTableArgs.__new__(DatabaseSyncedDatabaseTableArgs)

            __props__.__dict__["database_instance_name"] = database_instance_name
            __props__.__dict__["logical_database_name"] = logical_database_name
            __props__.__dict__["name"] = name
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["spec"] = spec
            __props__.__dict__["data_synchronization_status"] = None
            __props__.__dict__["effective_database_instance_name"] = None
            __props__.__dict__["effective_logical_database_name"] = None
            __props__.__dict__["unity_catalog_provisioning_state"] = None
        super(DatabaseSyncedDatabaseTable, __self__).__init__(
            'databricks:index/databaseSyncedDatabaseTable:DatabaseSyncedDatabaseTable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            data_synchronization_status: Optional[pulumi.Input[Union['DatabaseSyncedDatabaseTableDataSynchronizationStatusArgs', 'DatabaseSyncedDatabaseTableDataSynchronizationStatusArgsDict']]] = None,
            database_instance_name: Optional[pulumi.Input[_builtins.str]] = None,
            effective_database_instance_name: Optional[pulumi.Input[_builtins.str]] = None,
            effective_logical_database_name: Optional[pulumi.Input[_builtins.str]] = None,
            logical_database_name: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['DatabaseSyncedDatabaseTableProviderConfigArgs', 'DatabaseSyncedDatabaseTableProviderConfigArgsDict']]] = None,
            spec: Optional[pulumi.Input[Union['DatabaseSyncedDatabaseTableSpecArgs', 'DatabaseSyncedDatabaseTableSpecArgsDict']]] = None,
            unity_catalog_provisioning_state: Optional[pulumi.Input[_builtins.str]] = None) -> 'DatabaseSyncedDatabaseTable':
        """
        Get an existing DatabaseSyncedDatabaseTable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DatabaseSyncedDatabaseTableDataSynchronizationStatusArgs', 'DatabaseSyncedDatabaseTableDataSynchronizationStatusArgsDict']] data_synchronization_status: (SyncedTableStatus) - Synced Table data synchronization status
        :param pulumi.Input[_builtins.str] database_instance_name: Name of the target database instance. This is required when creating synced database tables in standard catalogs.
               This is optional when creating synced database tables in registered catalogs. If this field is specified
               when creating synced database tables in registered catalogs, the database instance name MUST
               match that of the registered catalog (or the request will be rejected)
        :param pulumi.Input[_builtins.str] effective_database_instance_name: (string) - The name of the database instance that this table is registered to. This field is always returned, and for
               tables inside database catalogs is inferred database instance associated with the catalog.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.str] effective_logical_database_name: (string) - The name of the logical database that this table is registered to.
               This is an output only field that contains the value computed from the input field combined with
               server side defaults. Use the field without the effective_ prefix to set the value
        :param pulumi.Input[_builtins.str] logical_database_name: Target Postgres database object (logical database) name for this table.
               
               When creating a synced table in a registered Postgres catalog, the
               target Postgres database name is inferred to be that of the registered catalog.
               If this field is specified in this scenario, the Postgres database name MUST
               match that of the registered catalog (or the request will be rejected).
               
               When creating a synced table in a standard catalog, this field is required.
               In this scenario, specifying this field will allow targeting an arbitrary postgres database.
               Note that this has implications for the `create_database_objects_is_missing` field in `spec`
        :param pulumi.Input[_builtins.str] name: Full three-part (catalog, schema, table) name of the table
        :param pulumi.Input[Union['DatabaseSyncedDatabaseTableProviderConfigArgs', 'DatabaseSyncedDatabaseTableProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] unity_catalog_provisioning_state: (string) - The provisioning state of the synced table entity in Unity Catalog. This is distinct from the
               state of the data synchronization pipeline (i.e. the table may be in "ACTIVE" but the pipeline
               may be in "PROVISIONING" as it runs asynchronously). Possible values are: `ACTIVE`, `DEGRADED`, `DELETING`, `FAILED`, `PROVISIONING`, `UPDATING`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseSyncedDatabaseTableState.__new__(_DatabaseSyncedDatabaseTableState)

        __props__.__dict__["data_synchronization_status"] = data_synchronization_status
        __props__.__dict__["database_instance_name"] = database_instance_name
        __props__.__dict__["effective_database_instance_name"] = effective_database_instance_name
        __props__.__dict__["effective_logical_database_name"] = effective_logical_database_name
        __props__.__dict__["logical_database_name"] = logical_database_name
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["spec"] = spec
        __props__.__dict__["unity_catalog_provisioning_state"] = unity_catalog_provisioning_state
        return DatabaseSyncedDatabaseTable(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="dataSynchronizationStatus")
    def data_synchronization_status(self) -> pulumi.Output['outputs.DatabaseSyncedDatabaseTableDataSynchronizationStatus']:
        """
        (SyncedTableStatus) - Synced Table data synchronization status
        """
        return pulumi.get(self, "data_synchronization_status")

    @_builtins.property
    @pulumi.getter(name="databaseInstanceName")
    def database_instance_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the target database instance. This is required when creating synced database tables in standard catalogs.
        This is optional when creating synced database tables in registered catalogs. If this field is specified
        when creating synced database tables in registered catalogs, the database instance name MUST
        match that of the registered catalog (or the request will be rejected)
        """
        return pulumi.get(self, "database_instance_name")

    @_builtins.property
    @pulumi.getter(name="effectiveDatabaseInstanceName")
    def effective_database_instance_name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The name of the database instance that this table is registered to. This field is always returned, and for
        tables inside database catalogs is inferred database instance associated with the catalog.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_database_instance_name")

    @_builtins.property
    @pulumi.getter(name="effectiveLogicalDatabaseName")
    def effective_logical_database_name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The name of the logical database that this table is registered to.
        This is an output only field that contains the value computed from the input field combined with
        server side defaults. Use the field without the effective_ prefix to set the value
        """
        return pulumi.get(self, "effective_logical_database_name")

    @_builtins.property
    @pulumi.getter(name="logicalDatabaseName")
    def logical_database_name(self) -> pulumi.Output[_builtins.str]:
        """
        Target Postgres database object (logical database) name for this table.

        When creating a synced table in a registered Postgres catalog, the
        target Postgres database name is inferred to be that of the registered catalog.
        If this field is specified in this scenario, the Postgres database name MUST
        match that of the registered catalog (or the request will be rejected).

        When creating a synced table in a standard catalog, this field is required.
        In this scenario, specifying this field will allow targeting an arbitrary postgres database.
        Note that this has implications for the `create_database_objects_is_missing` field in `spec`
        """
        return pulumi.get(self, "logical_database_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Full three-part (catalog, schema, table) name of the table
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.DatabaseSyncedDatabaseTableProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def spec(self) -> pulumi.Output[Optional['outputs.DatabaseSyncedDatabaseTableSpec']]:
        return pulumi.get(self, "spec")

    @_builtins.property
    @pulumi.getter(name="unityCatalogProvisioningState")
    def unity_catalog_provisioning_state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The provisioning state of the synced table entity in Unity Catalog. This is distinct from the
        state of the data synchronization pipeline (i.e. the table may be in "ACTIVE" but the pipeline
        may be in "PROVISIONING" as it runs asynchronously). Possible values are: `ACTIVE`, `DEGRADED`, `DELETING`, `FAILED`, `PROVISIONING`, `UPDATING`
        """
        return pulumi.get(self, "unity_catalog_provisioning_state")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAwsCrossAccountPolicyResult',
    'AwaitableGetAwsCrossAccountPolicyResult',
    'get_aws_cross_account_policy',
    'get_aws_cross_account_policy_output',
]

@pulumi.output_type
class GetAwsCrossAccountPolicyResult:
    """
    A collection of values returned by getAwsCrossAccountPolicy.
    """
    def __init__(__self__, aws_account_id=None, aws_partition=None, id=None, json=None, pass_roles=None, policy_type=None, region=None, security_group_id=None, vpc_id=None):
        if aws_account_id and not isinstance(aws_account_id, str):
            raise TypeError("Expected argument 'aws_account_id' to be a str")
        pulumi.set(__self__, "aws_account_id", aws_account_id)
        if aws_partition and not isinstance(aws_partition, str):
            raise TypeError("Expected argument 'aws_partition' to be a str")
        pulumi.set(__self__, "aws_partition", aws_partition)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if json and not isinstance(json, str):
            raise TypeError("Expected argument 'json' to be a str")
        pulumi.set(__self__, "json", json)
        if pass_roles and not isinstance(pass_roles, list):
            raise TypeError("Expected argument 'pass_roles' to be a list")
        pulumi.set(__self__, "pass_roles", pass_roles)
        if policy_type and not isinstance(policy_type, str):
            raise TypeError("Expected argument 'policy_type' to be a str")
        pulumi.set(__self__, "policy_type", policy_type)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if security_group_id and not isinstance(security_group_id, str):
            raise TypeError("Expected argument 'security_group_id' to be a str")
        pulumi.set(__self__, "security_group_id", security_group_id)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "aws_account_id")

    @_builtins.property
    @pulumi.getter(name="awsPartition")
    def aws_partition(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "aws_partition")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def json(self) -> _builtins.str:
        """
        AWS IAM Policy JSON document
        """
        return pulumi.get(self, "json")

    @_builtins.property
    @pulumi.getter(name="passRoles")
    def pass_roles(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "pass_roles")

    @_builtins.property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "policy_type")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "security_group_id")

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "vpc_id")


class AwaitableGetAwsCrossAccountPolicyResult(GetAwsCrossAccountPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAwsCrossAccountPolicyResult(
            aws_account_id=self.aws_account_id,
            aws_partition=self.aws_partition,
            id=self.id,
            json=self.json,
            pass_roles=self.pass_roles,
            policy_type=self.policy_type,
            region=self.region,
            security_group_id=self.security_group_id,
            vpc_id=self.vpc_id)


def get_aws_cross_account_policy(aws_account_id: Optional[_builtins.str] = None,
                                 aws_partition: Optional[_builtins.str] = None,
                                 pass_roles: Optional[Sequence[_builtins.str]] = None,
                                 policy_type: Optional[_builtins.str] = None,
                                 region: Optional[_builtins.str] = None,
                                 security_group_id: Optional[_builtins.str] = None,
                                 vpc_id: Optional[_builtins.str] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAwsCrossAccountPolicyResult:
    """
    This data source constructs necessary AWS cross-account policy for you, which is based on [official documentation](https://docs.databricks.com/administration-guide/account-api/iam-role.html#language-Your%C2%A0VPC,%C2%A0default).

    > This data source can be used with an account or workspace-level provider.

    ## Example Usage

    For more detailed usage please see get_aws_assume_role_policy or databricks_aws_s3_mount pages.

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_aws_cross_account_policy()
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Provisioning AWS Databricks workspaces with a Hub & Spoke firewall for data exfiltration protection guide
    * get_aws_assume_role_policy data to construct the necessary AWS STS assume role policy.
    * get_aws_bucket_policy data to configure a simple access policy for AWS S3 buckets, so that Databricks can access data in it.
    * InstanceProfile to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount.


    :param _builtins.str aws_account_id: — Your AWS account ID, which is a number.
    :param _builtins.str aws_partition: AWS partition. The options are `aws`, `aws-us-gov`, or `aws-us-gov-dod`. Defaults to `aws`
    :param Sequence[_builtins.str] pass_roles: List of Data IAM role ARNs that are explicitly granted `iam:PassRole` action.
           The below arguments are only valid for `restricted` policy type
    :param _builtins.str policy_type: The type of cross account policy to generated: `managed` for Databricks-managed VPC and `customer` for customer-managed VPC, `restricted` for customer-managed VPC with policy restrictions
    :param _builtins.str region: — AWS Region name for your VPC deployment, for example `us-west-2`.
    :param _builtins.str security_group_id: — ID of your AWS security group. When you add a security group restriction, you cannot reuse the cross-account IAM role or reference a credentials ID (`credentials_id`) for any other workspaces. For those other workspaces, you must create separate roles, policies, and credentials objects.
    :param _builtins.str vpc_id: — ID of the AWS VPC where you want to launch workspaces.
    """
    __args__ = dict()
    __args__['awsAccountId'] = aws_account_id
    __args__['awsPartition'] = aws_partition
    __args__['passRoles'] = pass_roles
    __args__['policyType'] = policy_type
    __args__['region'] = region
    __args__['securityGroupId'] = security_group_id
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getAwsCrossAccountPolicy:getAwsCrossAccountPolicy', __args__, opts=opts, typ=GetAwsCrossAccountPolicyResult).value

    return AwaitableGetAwsCrossAccountPolicyResult(
        aws_account_id=pulumi.get(__ret__, 'aws_account_id'),
        aws_partition=pulumi.get(__ret__, 'aws_partition'),
        id=pulumi.get(__ret__, 'id'),
        json=pulumi.get(__ret__, 'json'),
        pass_roles=pulumi.get(__ret__, 'pass_roles'),
        policy_type=pulumi.get(__ret__, 'policy_type'),
        region=pulumi.get(__ret__, 'region'),
        security_group_id=pulumi.get(__ret__, 'security_group_id'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_aws_cross_account_policy_output(aws_account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        aws_partition: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        pass_roles: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                                        policy_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        security_group_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        vpc_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAwsCrossAccountPolicyResult]:
    """
    This data source constructs necessary AWS cross-account policy for you, which is based on [official documentation](https://docs.databricks.com/administration-guide/account-api/iam-role.html#language-Your%C2%A0VPC,%C2%A0default).

    > This data source can be used with an account or workspace-level provider.

    ## Example Usage

    For more detailed usage please see get_aws_assume_role_policy or databricks_aws_s3_mount pages.

    ```python
    import pulumi
    import pulumi_databricks as databricks

    this = databricks.get_aws_cross_account_policy()
    ```

    ## Related Resources

    The following resources are used in the same context:

    * Provisioning AWS Databricks workspaces with a Hub & Spoke firewall for data exfiltration protection guide
    * get_aws_assume_role_policy data to construct the necessary AWS STS assume role policy.
    * get_aws_bucket_policy data to configure a simple access policy for AWS S3 buckets, so that Databricks can access data in it.
    * InstanceProfile to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount.


    :param _builtins.str aws_account_id: — Your AWS account ID, which is a number.
    :param _builtins.str aws_partition: AWS partition. The options are `aws`, `aws-us-gov`, or `aws-us-gov-dod`. Defaults to `aws`
    :param Sequence[_builtins.str] pass_roles: List of Data IAM role ARNs that are explicitly granted `iam:PassRole` action.
           The below arguments are only valid for `restricted` policy type
    :param _builtins.str policy_type: The type of cross account policy to generated: `managed` for Databricks-managed VPC and `customer` for customer-managed VPC, `restricted` for customer-managed VPC with policy restrictions
    :param _builtins.str region: — AWS Region name for your VPC deployment, for example `us-west-2`.
    :param _builtins.str security_group_id: — ID of your AWS security group. When you add a security group restriction, you cannot reuse the cross-account IAM role or reference a credentials ID (`credentials_id`) for any other workspaces. For those other workspaces, you must create separate roles, policies, and credentials objects.
    :param _builtins.str vpc_id: — ID of the AWS VPC where you want to launch workspaces.
    """
    __args__ = dict()
    __args__['awsAccountId'] = aws_account_id
    __args__['awsPartition'] = aws_partition
    __args__['passRoles'] = pass_roles
    __args__['policyType'] = policy_type
    __args__['region'] = region
    __args__['securityGroupId'] = security_group_id
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getAwsCrossAccountPolicy:getAwsCrossAccountPolicy', __args__, opts=opts, typ=GetAwsCrossAccountPolicyResult)
    return __ret__.apply(lambda __response__: GetAwsCrossAccountPolicyResult(
        aws_account_id=pulumi.get(__response__, 'aws_account_id'),
        aws_partition=pulumi.get(__response__, 'aws_partition'),
        id=pulumi.get(__response__, 'id'),
        json=pulumi.get(__response__, 'json'),
        pass_roles=pulumi.get(__response__, 'pass_roles'),
        policy_type=pulumi.get(__response__, 'policy_type'),
        region=pulumi.get(__response__, 'region'),
        security_group_id=pulumi.get(__response__, 'security_group_id'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))
